% EXAMPLE HELIX APPENDIX
%
% Here we present a step-by-step example on how PPA curvilinear components
% and projections are computed on an illustrative manifold of well defined
% geometry which also has practical interest in communication problems and
% served as test case for Principal Curves Methods \cite{Ozertem11}: the 3d-helix
% corrupted with additive Gaussian noise.
% 
% This code generates figures equivalent to figure 9 of the paper 
% Laparra et al. Principal Polynomial Analysis IJNS 2014
% It does not reproduces exactly the same figure due to the random choice
% of the training samples.
% 

% DATA

    % Dimension of the space where the helix is embedded:
        
        DIM = 3;        
           
    % Helix parameters:
        
        a = 2;
        b = 0.8;
        t = linspace(0,6*pi,2000);
        x = a*cos(t);
        y = a*sin(t);
        sel_sample = 900;   % I increase the radius of the selected sample for illustrative purposes
        x(sel_sample) = 1.6*a*cos(t(sel_sample));
        y(sel_sample) = 1.6*a*sin(t(sel_sample));
        z = b*t;       
    
    % Theoretical curvatures:
    
        cur = a/(a^2+b^2); % Curvatura
        tor = b/(a^2+b^2); % Torsion
        
    % Generate data in d dimensions (d = DIM):
    
        raspa_orig = [x; y; z];        
        
    %  We apply an arbitrary rotation (the one selected is just because it is nice):
       
            %angulos = round(360*rand(1,3));
            angulos = [194    48    82];
            % angulos = [0 0 0];            
        
            a1 = angulos(1)*pi/180;
            a2 = angulos(2)*pi/180;
            a3 = angulos(3)*pi/180;

            
            M1 = [cos(a1) -sin(a1) 0;sin(a1) cos(a1) 0;0 0 1];
            M2 = [cos(a2) 0 -sin(a2);0 1 0;sin(a2) 0 cos(a2)];
            M3 = [1 0 0;0 cos(a3) -sin(a3);0 sin(a3) cos(a3)];
            
            M = M3*M2*M1;
                                
        %  DIM = 5:        
        
            %v = rand(DIM,1);
            %M=[v/norm(v) ortc(v/norm(v))];
        
        % General:
        
            %M = rand(DIM);
            %M = M*inv(sqrtm(M'*M));                % orthogonalization
            %M = M/(abs(det(M))^(1/size(M,1)));     % normalization
            
        raspa = M*raspa_orig;
        
    % Data from the helix and noise:
                
    ruidos = [0.1 0.3 0.6];
    r = 2; % Noise level
        close all
        ruido  = ruidos(r);
        x_dat = raspa + ruido*randn(DIM,length(raspa(1,:)));
        x_dat(:,sel_sample) =  raspa(:,sel_sample);
  
        media = mean(x_dat')';
        x_dat = x_dat-repmat(media,1,length(x_dat(1,:)));
        
 %% Apply PPA:

        max_orden = 25;
        
        [datT Res_PPA] = PPA_auto(x_dat(:,1:30:end),x_dat(:,2:30:end),max_orden,DIM,0,0,0,0);
        [datT Results] = apply_PPA(x_dat,Res_PPA);

        E = Res_PPA(1).Res.V;
        e1 = E(:,1);
        
        datE1 = E'*x_dat;
        
        % pos2 = [media(1) + datE1(1,:)*E(1,1);media(2) + datE1(1,:)*E(2,1);media(3) + datE1(1,:)*E(3,1)] ...
        %       + [media(1) + datE1(2,:)*E(1,2);media(2) + datE1(2,:)*E(2,2);media(3) + datE1(2,:)*E(3,2)]
           
        pos1 = [datE1(1,:)*E(1,1);datE1(1,:)*E(2,1);datE1(1,:)*E(3,1)];
         
        pos2 = [datE1(1,:)*E(1,1);datE1(1,:)*E(2,1);datE1(1,:)*E(3,1)] ...
               + [datE1(2,:)*E(1,2);datE1(2,:)*E(2,2);datE1(2,:)*E(3,2)] ...
                 + repmat(-8*E(:,3),1,length(x_dat(1,:)));    
        
        pos3 = [datE1(1,:)*E(1,1);datE1(1,:)*E(2,1);datE1(1,:)*E(3,1)] ...
               + [datE1(3,:)*E(1,3);datE1(3,:)*E(2,3);datE1(3,:)*E(3,3)] ...
                 + repmat(-8*E(:,2),1,length(x_dat(1,:)));    

             
% Gray dots of panel (a) represent the input 3d samples, $\mathbf{x}_0$.
% See some representative sample highlighted in black.
%
% In the PCA-based solution, the leading vector $\mathbf{e}_1$ and some basis of the
% orthogonal subspace, $\mathbf{E}_1$ are selected from the diagonalization
% of the covariance matrix of $\mathbf{x}_0$. In the example, $\mathbf{e}_1$ 
% (the eigenvector of bigger eigenvalue) is depicted in orange, and the vectors 
% in $\mathbf{E}_1$ in green and blue respectively.
%
% The first PPA component, $\alpha_1$, is the projection onto the first leading vector
% (orange dots and the circle for the highlighted sample).

        LW = 1.5;
        FS = 25;
        
        % DATA
        
        figure(1),plot3(x_dat(1,1:3:end),x_dat(2,1:3:end),x_dat(3,1:3:end),'.','color',[0.65 0.65 0.65])
        hold on,plot3(x_dat(1,sel_sample),x_dat(2,sel_sample),x_dat(3,sel_sample),'o','color',[0 0 0],'linewidth',2*LW,'markersize',8)
        axis equal 
        view([-64 -30])
        axis off             

        % BASIS 1
        figure(1),hold on,plot3([10*e1(1) 12*e1(1)],[10*e1(2) 12*e1(2)],[10*e1(3) 12*e1(3)],'-','color',[1 0.5 0],'linewidth',2*LW) 
                          plot3([10*e1(1) 10*e1(1)+2*E(1,2)],[10*e1(2) 10*e1(2)+2*E(2,2)],[10*e1(3) 10*e1(3)+2*E(3,2)],'color',[0 0.9 0],'linewidth',2*LW)                    
                          plot3([10*e1(1) 10*e1(1)+2*E(1,3)],[10*e1(2) 10*e1(2)+2*E(2,3)],[10*e1(3) 10*e1(3)+2*E(3,3)],'color',[0 0.7 1],'linewidth',2*LW)                    
                          
        % LINE e1
        figure(1),hold on,plot3([0 10*e1(1)],[0 10*e1(2)],[0 10*e1(3)],'k-') 
                          plot3([0 -10*e1(1)],[0 -10*e1(2)],[0 -10*e1(3)],'k-')  
             
        % Projection onto e1
        figure(1),hold on,plot3(pos1(1,1:5:end),pos1(2,1:5:end),pos1(3,1:5:end),'.','color',[1 0.5 0]), % Projections onto e1                   
                          plot3(pos1(1,sel_sample),pos1(2,sel_sample),pos1(3,sel_sample),'o','color',[1 0.5 0],'linewidth',2*LW,'markersize',8), % Projection onto e1
                          plot3([pos1(1,sel_sample) x_dat(1,sel_sample)],[pos1(2,sel_sample) x_dat(2,sel_sample)],[pos1(3,sel_sample) x_dat(3,sel_sample)],'--','color',[0 0 0],'linewidth',LW,'markersize',8)
                          axis equal
                          
                          
        figure(1),hold on,text(13*e1(1),13*e1(2),13*e1(3),'PC 1','fontsize',FS,'color',[1 0.5 0]) 
                          text(10*e1(1)+3*E(1,2),10*e1(2)+3*E(2,2),10*e1(3)+3*E(3,2),'PC 2','fontsize',FS,'color',[0 0.9 0])
                          text(10*e1(1)+3*E(1,3),10*e1(2)+3*E(2,3),10*e1(3)+3*E(3,3),'PC 3','fontsize',FS,'color',[0 0.7 1])
                          
% The conditional mean, $\mathbf{m}_1$, in the subspace orthogonal to $\mathbf{e}_1$ strongly 
% depends on $\alpha_1$. Therefore, 

% To remove the dependence of the conditional mean along the $\mathbf{e}_1$ direction 
% we fit a polynomial with coeffcients $\mathbf{W}_1$ to estimate $\mathbf{m}_1$ from 
% $\alpha_1$ according to Eq. 7. 
% The coefficients of the polynomial are those such that the average squared distance 
% to $\mathbf{\hat{m}}_1 $ in the subspace $\mathbf{E}_1$ is minimized (Eq. 6). 
% This implies that the minimization of the sum of squares of the distances to
% the polynomial emmbedded in the d-dimensional space (segment in red) is equivalent 
% to the minimization of the sum of the squares of their components: the distances to 
% the d-1 1d-curves (segments in dark green and blue), which as stated in
% Property I, does not depend on $\mathbf{E}_1$.
%  
% 

        % DATA
        figure(2),plot3(x_dat(1,1:3:end),x_dat(2,1:3:end),x_dat(3,1:3:end),'.','color',[0.65 0.65 0.65])
        hold on,plot3(x_dat(1,sel_sample),x_dat(2,sel_sample),x_dat(3,sel_sample),'o','color',[0 0 0],'linewidth',2*LW,'markersize',8)
        axis equal 
        view([-64 -30])
        axis off             

        % BASIS 1
        figure(2),hold on,plot3([10*e1(1) 12*e1(1)],[10*e1(2) 12*e1(2)],[10*e1(3) 12*e1(3)],'-','color',[1 0.5 0],'linewidth',2*LW) 
                          plot3([10*e1(1) 10*e1(1)+2*E(1,2)],[10*e1(2) 10*e1(2)+2*E(2,2)],[10*e1(3) 10*e1(3)+2*E(3,2)],'color',[0 0.9 0],'linewidth',2*LW)                    
                          plot3([10*e1(1) 10*e1(1)+2*E(1,3)],[10*e1(2) 10*e1(2)+2*E(2,3)],[10*e1(3) 10*e1(3)+2*E(3,3)],'color',[0 0.7 1],'linewidth',2*LW)                    
                          
        % LINE e1
        figure(2),hold on,plot3([0 10*e1(1)],[0 10*e1(2)],[0 10*e1(3)],'k-') 
                          plot3([0 -10*e1(1)],[0 -10*e1(2)],[0 -10*e1(3)],'k-')  
             
        % Projection onto e1
        figure(2),hold on,plot3(pos1(1,1:5:end),pos1(2,1:5:end),pos1(3,1:5:end),'.','color',[1 0.5 0]), % Projections onto e1                   
                          plot3(pos1(1,sel_sample),pos1(2,sel_sample),pos1(3,sel_sample),'o','color',[1 0.5 0],'linewidth',2*LW,'markersize',8), % Projection onto e1
                          plot3([pos1(1,sel_sample) x_dat(1,sel_sample)],[pos1(2,sel_sample) x_dat(2,sel_sample)],[pos1(3,sel_sample) x_dat(3,sel_sample)],'--','color',[0 0 0],'linewidth',LW,'markersize',8)
                          axis equal
                          
%         figure(2),hold on,text(13*e1(1),13*e1(2),13*e1(3),'PC 1','fontsize',FS,'color',[1 0.5 0]) 
%                           text(10*e1(1)+3*E(1,2),10*e1(2)+3*E(2,2),10*e1(3)+3*E(3,2),'PC 2','fontsize',FS,'color',[0 0.9 0])
%                           text(10*e1(1)+3*E(1,3),10*e1(2)+3*E(2,3),10*e1(3)+3*E(3,3),'PC 3','fontsize',FS,'color',[0 0.7 1])                          
                          
        % Projections onto e1,e2 and e1,e3
        figure(2),hold on,plot3(pos2(1,1:3:end),pos2(2,1:3:end),pos2(3,1:3:end),'g.'), % Projections onto e1,e2             
        figure(2),hold on,plot3(pos3(1,1:3:end),pos3(2,1:3:end),pos3(3,1:3:end),'.','color',[0 0.7 1]), % Projections onto e1,e3
          plot3(pos2(1,sel_sample),pos2(2,sel_sample),pos2(3,sel_sample),'o','color',[0 0.5 0],'linewidth',2*LW,'markersize',8), % Projections onto e1,e2  
          plot3(pos3(1,sel_sample),pos3(2,sel_sample),pos3(3,sel_sample),'o','color',[0 0 1],'linewidth',2*LW,'markersize',8), % Projections onto e1,e2  
       
        % PLANE e1,e2
        figure(2),hold on,plot3([0 9*e1(1)]-8*E(1,3)-4*E(1,2),[0 9*e1(2)]-8*E(2,3)-4*E(2,2),[0 9*e1(3)]-8*E(3,3)-4*E(3,2),'k-') 
                          plot3([0 9*e1(1)]-8*E(1,3)+4*E(1,2),[0 9*e1(2)]-8*E(2,3)+4*E(2,2),[0 9*e1(3)]-8*E(3,3)+4*E(3,2),'k-') 
                          plot3([0 -9*e1(1)]-8*E(1,3)-4*E(1,2),[0 -9*e1(2)]-8*E(2,3)-4*E(2,2),[0 -9*e1(3)]-8*E(3,3)-4*E(3,2),'k-') 
                          plot3([0 -9*e1(1)]-8*E(1,3)+4*E(1,2),[0 -9*e1(2)]-8*E(2,3)+4*E(2,2),[0 -9*e1(3)]-8*E(3,3)+4*E(3,2),'k-')                          

                          plot3([9*e1(1)-8*E(1,3)-4*E(1,2) 9*e1(1)-8*E(1,3)+4*E(1,2)],[9*e1(2)-8*E(2,3)-4*E(2,2) 9*e1(2)-8*E(2,3)+4*E(2,2)],[9*e1(3)-8*E(3,3)-4*E(3,2) 9*e1(3)-8*E(3,3)+4*E(3,2)],'k-')                           
                          plot3([-9*e1(1)-8*E(1,3)-4*E(1,2) -9*e1(1)-8*E(1,3)+4*E(1,2)],[-9*e1(2)-8*E(2,3)-4*E(2,2) -9*e1(2)-8*E(2,3)+4*E(2,2)],[-9*e1(3)-8*E(3,3)-4*E(3,2) -9*e1(3)-8*E(3,3)+4*E(3,2)],'k-') 
                          
                          
                          plot3([0 -10*e1(1)]-8*E(1,3),[0 -10*e1(2)]-8*E(2,3),[0 -10*e1(3)]-8*E(3,3),'k-') % Axis e1 in the plane
                          plot3([0 -10*e1(1)]-8*E(1,3),[0 -10*e1(2)]-8*E(2,3),[0 -10*e1(3)]-8*E(3,3),'k-')                          
                          plot3([0 10*e1(1)]-8*E(1,3),[0 10*e1(2)]-8*E(2,3),[0 10*e1(3)]-8*E(3,3),'k-') 
                          plot3([0 10*e1(1)]-8*E(1,3),[0 10*e1(2)]-8*E(2,3),[0 10*e1(3)]-8*E(3,3),'k-')                          
                          
        % PLANE e1,e3
        figure(2),hold on,plot3([0 9*e1(1)]-8*E(1,2)-4*E(1,3),[0 9*e1(2)]-8*E(2,2)-4*E(2,3),[0 9*e1(3)]-8*E(3,2)-4*E(3,3),'k-') 
                          plot3([0 9*e1(1)]-8*E(1,2)+4*E(1,3),[0 9*e1(2)]-8*E(2,2)+4*E(2,3),[0 9*e1(3)]-8*E(3,2)+4*E(3,3),'k-') 
                          plot3([0 -9*e1(1)]-8*E(1,2)-4*E(1,3),[0 -9*e1(2)]-8*E(2,2)-4*E(2,3),[0 -9*e1(3)]-8*E(3,2)-4*E(3,3),'k-') 
                          plot3([0 -9*e1(1)]-8*E(1,2)+4*E(1,3),[0 -9*e1(2)]-8*E(2,2)+4*E(2,3),[0 -9*e1(3)]-8*E(3,2)+4*E(3,3),'k-')                          

                          plot3([9*e1(1)-8*E(1,2)-4*E(1,3) 9*e1(1)-8*E(1,2)+4*E(1,3)],[9*e1(2)-8*E(2,2)-4*E(2,3) 9*e1(2)-8*E(2,2)+4*E(2,3)],[9*e1(3)-8*E(3,2)-4*E(3,3) 9*e1(3)-8*E(3,2)+4*E(3,3)],'k-')                           
                          plot3([-9*e1(1)-8*E(1,2)-4*E(1,3) -9*e1(1)-8*E(1,2)+4*E(1,3)],[-9*e1(2)-8*E(2,2)-4*E(2,3) -9*e1(2)-8*E(2,2)+4*E(2,3)],[-9*e1(3)-8*E(3,2)-4*E(3,3) -9*e1(3)-8*E(3,2)+4*E(3,3)],'k-') 
                          
                          plot3([0 -10*e1(1)]-8*E(1,2),[0 -10*e1(2)]-8*E(2,2),[0 -10*e1(3)]-8*E(3,2),'k-') % Axis e1 in the plane
                          plot3([0 -10*e1(1)]-8*E(1,2),[0 -10*e1(2)]-8*E(2,2),[0 -10*e1(3)]-8*E(3,2),'k-')
                          plot3([0 10*e1(1)]-8*E(1,2),[0 10*e1(2)]-8*E(2,2),[0 10*e1(3)]-8*E(3,2),'k-') % Axis e1 in the plane
                          plot3([0 10*e1(1)]-8*E(1,2),[0 10*e1(2)]-8*E(2,2),[0 10*e1(3)]-8*E(3,2),'k-')                          
        
        axis equal   
                
      
%  figure(2), plot3(datT(1,:),datT(2,:),datT(3,:),'b.')
%  axis equal

    % Calculamos una retícula unidimensional en el espacio transformado PPA 
    % y la invertimos al espacio original: 

        % Dominio PPA:
              
           num_pasos = 200;
           num_pasos2 = 20;
           reticula_ppa = [linspace(0.95*min(datT(1,:)),0.95*max(datT(1,:)),num_pasos); zeros(DIM-1,num_pasos)]; 
           reticula_ppa2 = [linspace(0.95*min(datT(1,:)),0.95*max(datT(1,:)),num_pasos2); zeros(DIM-1,num_pasos2)]; 
            
           figure(3), plot3(datT(1,1:10:end),datT(2,1:10:end),datT(3,1:10:end),'r.')
           hold on, plot3(reticula_ppa(1,:),reticula_ppa(2,:),reticula_ppa(3,:),'b-.')
           axis equal

        % Dominio original:
        
           x_reticula = inv_PPA(reticula_ppa,Res_PPA);
           x_reticula2 = inv_PPA(reticula_ppa2,Res_PPA);
           
           figure(4), 
           plot3(x_reticula(1,:),x_reticula(2,:),x_reticula(3,:),'-','color',[0.65 0.65 0.65],'linewidth',LW)
           hold on, plot3(raspa(1,:),raspa(2,:),raspa(3,:),'c-','linewidth',LW)
           axis equal 
           view([-64 -30])
        
           menos = 5;   
           figure(2),hold on,plot3(x_reticula(1,menos:2:end-menos),x_reticula(2,menos:2:end-menos),x_reticula(3,menos:2:end-menos),'-','color',[1 0 0],'linewidth',2*LW)
        
           x_reticula_proj = E'*x_reticula;
           
        pos22 = [x_reticula_proj(1,:)*E(1,1);x_reticula_proj(1,:)*E(2,1);x_reticula_proj(1,:)*E(3,1)] ...
               + [x_reticula_proj(2,:)*E(1,2);x_reticula_proj(2,:)*E(2,2);x_reticula_proj(2,:)*E(3,2)] ...
                 + repmat(-8*E(:,3),1,length(x_reticula_proj(1,:)));    
        
        pos33 = [x_reticula_proj(1,:)*E(1,1);x_reticula_proj(1,:)*E(2,1);x_reticula_proj(1,:)*E(3,1)] ...
               + [x_reticula_proj(3,:)*E(1,3);x_reticula_proj(3,:)*E(2,3);x_reticula_proj(3,:)*E(3,3)] ...
                 + repmat(-8*E(:,2),1,length(x_reticula_proj(1,:)));    

         
        figure(2),hold on,plot3(pos33(1,menos:2:end-menos),pos33(2,menos:2:end-menos),pos33(3,menos:2:end-menos),'b-','linewidth',2*LW), % Projections onto e1,e2             
        figure(2),hold on,plot3(pos22(1,menos:2:end-menos),pos22(2,menos:2:end-menos),pos22(3,menos:2:end-menos),'color',[0 0.5 0],'linewidth',2*LW), % Projections onto e1,e3
           
        figure(2),hold on,plot3([pos1(1,sel_sample) pos1(1,sel_sample)-8*E(1,3)],[pos1(2,sel_sample) pos1(2,sel_sample)-8*E(2,3)],[pos1(3,sel_sample) pos1(3,sel_sample)-8*E(3,3)],'--','color',[0 0 0],'linewidth',LW)    
        figure(2),hold on,plot3([pos1(1,sel_sample) pos1(1,sel_sample)-8*E(1,2)],[pos1(2,sel_sample) pos1(2,sel_sample)-8*E(2,2)],[pos1(3,sel_sample) pos1(3,sel_sample)-8*E(3,2)],'--','color',[0 0 0],'linewidth',LW)    
        
        figure(2),hold on,plot3([pos1(1,sel_sample)-8*E(1,3) pos2(1,sel_sample)],[pos1(2,sel_sample)-8*E(2,3) pos2(2,sel_sample)], [pos1(3,sel_sample)-8*E(3,3) pos2(3,sel_sample)],'--','color',[0 0 0],'linewidth',LW)            
        figure(2),hold on,plot3([pos1(1,sel_sample)-8*E(1,2) pos3(1,sel_sample)],[pos1(2,sel_sample)-8*E(2,2) pos3(2,sel_sample)], [pos1(3,sel_sample)-8*E(3,2) pos3(3,sel_sample)],'--','color',[0 0 0],'linewidth',LW)                    
        
        W = Res_PPA(1).Res.W;
        ord = Res_PPA(1).ord;
        v = my_vander(datE1(1,sel_sample),ord);
        m = W'*v;
        
        x_pol_sel = E*[datE1(1,sel_sample);m];                           % Position in the 3d polynomial
        pos22_sel = datE1(1,sel_sample)*E(:,1) + m(1)*E(:,2) -8*E(:,3);  % Position in the first 1d polynomial
        pos33_sel = datE1(1,sel_sample)*E(:,1) + m(2)*E(:,3) -8*E(:,2);  % Position in the second 1d polynomial
        
        figure(2),hold on,plot3(x_pol_sel(1),x_pol_sel(2),x_pol_sel(3),'s','color',[1 0 0],'linewidth',3*LW,'markersize',8)
        figure(2),hold on,plot3( pos22_sel(1), pos22_sel(2), pos22_sel(3),'s','color',[0 0.5 0],'linewidth',3*LW,'markersize',8)
        figure(2),hold on,plot3( pos33_sel(1), pos33_sel(2), pos33_sel(3),'s','color',[0 0 1],'linewidth',3*LW,'markersize',8)
        
        figure(2),hold on,plot3([x_pol_sel(1) x_dat(1,sel_sample)],[x_pol_sel(2) x_dat(2,sel_sample)],[x_pol_sel(3) x_dat(3,sel_sample)],'-','color',[1 0 0],'linewidth',3*LW,'markersize',8)
        figure(2),hold on,plot3([pos22_sel(1) pos2(1,sel_sample)],[pos22_sel(2) pos2(2,sel_sample)],[pos22_sel(3) pos2(3,sel_sample)],'-','color',[0 0.5 0],'linewidth',3*LW,'markersize',8)
        figure(2),hold on,plot3([pos33_sel(1) pos3(1,sel_sample)],[pos33_sel(2) pos3(2,sel_sample)],[pos33_sel(3) pos3(3,sel_sample)],'-','color',[0 0 1],'linewidth',3*LW,'markersize',8)
        
        figure(2),hold on,text(1.1*x_reticula(1,end),1.1*x_reticula(2,end),1.1*x_reticula(3,end),'PP 1','fontsize',FS,'color',[1 0 0])
        
        hold on,plot3(x_dat(1,sel_sample),x_dat(2,sel_sample),x_dat(3,sel_sample),'o','color',[0 0 0],'linewidth',2*LW,'markersize',8)
        axis equal
         
% Once the polynomial is fitted we remove the estimated conditional mean $\mathbf{\hat{m}_1}(\alpha_1)$ 
% from each sample (each slice of the dataset is located along $\mathbf{e}_1$) and consider the residuals in the subspace
% $\mathbf{E}_1$. See plot (c). Summarizing the process in plots (a)-(c), i.e. the transform $R_1$, the first Principal Polynomial (red
% curve) accounts for the first curvilinear dimension of the data. Now
% we have $(d-1) = 2$ dimensions yet to be explained: these are the gray
% dots, $\mathbf{x}_1$, at plot (d).

        V = my_vander(datE1(1,:),ord);
        M = W'*V;
        
        x_pol = E*[0*datE1(1,:);M];
        
        x_dat_01 = x_dat - x_pol;  % Datos en el espacio 3d despues de restarles (a cada uno) la media condicional en el subespacio ortogonal
        
        x_dat_02 = x_dat - E*[datE1(1,:);M];  % Datos en el espacio 3d despues de restarles (a cada uno) la media condicional y su proyeccion en e_1 -> proyectados en e2,e3

        % DATA AFTER REMOVING THE ESTIMATED CONDITIONAL MEAN
        figure(3),clf,plot3(x_dat_01(1,1:5:end),x_dat_01(2,1:5:end),x_dat_01(3,1:5:end),'.','color',[0.85 0.85 0])
        figure(3),hold on,plot3([0 10*e1(1)],[0 10*e1(2)],[0 10*e1(3)],'k-') 
                          plot3([0 -10*e1(1)],[0 -10*e1(2)],[0 -10*e1(3)],'k-')  
             
        % CONDITIONAL MEANS IN THE ORIGiN (along e1) and
        figure(3),hold on,plot3(pos1(1,1:5:end),pos1(2,1:5:end),pos1(3,1:5:end),'.','color',[1 0 0],'linewidth',2*LW), % Projections onto e1 
        figure(3),hold on,plot3(pos1(1,sel_sample),pos1(2,sel_sample),pos1(3,sel_sample),'s','color',[1 0 0],'linewidth',2*LW), % Projections onto e1 
        figure(3),hold on,plot3([x_dat_01(1,sel_sample) pos1(1,sel_sample)],[x_dat_01(2,sel_sample) pos1(2,sel_sample)],[x_dat_01(3,sel_sample) pos1(3,sel_sample)],'-','color',[1 0 0],'linewidth',3*LW), % Projections onto e1 
                  hold on,plot3(x_dat_01(1,sel_sample),x_dat_01(2,sel_sample),x_dat_01(3,sel_sample),'o','color',[0 0 0],'linewidth',2*LW,'markersize',8), % Projection onto e1        
        axis off
                          
        % BASIS 1
        figure(3),hold on,plot3([10*e1(1) 12*e1(1)],[10*e1(2) 12*e1(2)],[10*e1(3) 12*e1(3)],'-','color',[1 0.5 0],'linewidth',2*LW) 
                          plot3([10*e1(1) 10*e1(1)+2*E(1,2)],[10*e1(2) 10*e1(2)+2*E(2,2)],[10*e1(3) 10*e1(3)+2*E(3,2)],'color',[0 0.9 0],'linewidth',2*LW)                    
                          plot3([10*e1(1) 10*e1(1)+2*E(1,3)],[10*e1(2) 10*e1(2)+2*E(2,3)],[10*e1(3) 10*e1(3)+2*E(3,3)],'color',[0 0.7 1],'linewidth',2*LW)    
                          axis equal  
                        
                          fact =4;
                          p1 = 16*e1 - fact*E(:,2) - fact*E(:,3);
                          p2 = 16*e1 + fact*E(:,2) - fact*E(:,3);
                          p3 = 16*e1 + fact*E(:,2) + fact*E(:,3);
                          p4 = 16*e1 - fact*E(:,2) + fact*E(:,3);
                          
        % PROJECTION ONTO THE ORTHOGONAL SUBSPACE
        figure(3),hold on,plot3(x_dat_02(1,1:5:end)+16*e1(1),x_dat_02(2,1:5:end)+16*e1(2),x_dat_02(3,1:5:end)+16*e1(3),'.','color',[0.65 0.65 0.65])   
                  hold on,plot3([p1(1) p2(1)],[p1(2) p2(2)],[p1(3) p2(3)],'-','color',[0 0 0])
                  hold on,plot3([p2(1) p3(1)],[p2(2) p3(2)],[p2(3) p3(3)],'-','color',[0 0 0])
                  hold on,plot3([p3(1) p4(1)],[p3(2) p4(2)],[p3(3) p4(3)],'-','color',[0 0 0])
                  hold on,plot3([p4(1) p1(1)],[p4(2) p1(2)],[p4(3) p1(3)],'-','color',[0 0 0])     
                  
        figure(3),hold on,plot3(16*e1(1),16*e1(2),16*e1(3),'s','color',[1 0 0],'linewidth',2*LW,'markersize',8),
                  hold on,plot3([16*e1(1) x_dat_02(1,sel_sample)+16*e1(1)],[16*e1(2) x_dat_02(2,sel_sample)+16*e1(2)],[16*e1(3) x_dat_02(3,sel_sample)+16*e1(3)],'-','color',[1 0 0],'linewidth',3*LW,'markersize',8) 
                  hold on,plot3(x_dat_02(1,sel_sample)+16*e1(1),x_dat_02(2,sel_sample)+16*e1(2),x_dat_02(3,sel_sample)+16*e1(3),'o','color',[0 0 0],'linewidth',2*LW,'markersize',8)              
                  
axis equal
view([-64 -30])

%
% DATA x_1
%
     
     x_dat_1 = E(:,2:3)'*x_dat - M;
     
                          p1 =  - fact*[1 0]' - fact*[0 1]';
                          p2 =  + fact*[1 0]' - fact*[0 1]';
                          p3 =  + fact*[1 0]' + fact*[0 1]';
                          p4 =  - fact*[1 0]' + fact*[0 1]';

% Data x_1                          
figure(4),clf,plot(x_dat_1(1,1:5:end),x_dat_1(2,1:5:end),'.','color',[0.65 0.65 0.65])
                  hold on,plot([p1(1) p2(1)],[p1(2) p2(2)],'-','color',[0 0 0])
                  hold on,plot([p2(1) p3(1)],[p2(2) p3(2)],'-','color',[0 0 0])
                  hold on,plot([p3(1) p4(1)],[p3(2) p4(2)],'-','color',[0 0 0])
                  hold on,plot([p4(1) p1(1)],[p4(2) p1(2)],'-','color',[0 0 0])
                  axis off
             
       % e2 and E2
       E2=Res_PPA(2).Res.V;
       e2 = E2(:,1);
        
       datE2 = E2'*x_dat_1;
           
       % Axis e2
       
       plot([-2.3*E2(1,1) 2.3*E2(1,1)],[-2.3*E2(2,1) 2.3*E2(2,1)],'-','color',[0 0 0]),
       
       plot(2.3*E2(1,1)+[0 1.5*E2(1,1)],2.3*E2(2,1)+[0 1.5*E2(2,1)],'-','color',[1 0.5 0],'linewidth',3*LW),
       plot(2.3*E2(1,1)+[0 1.5*E2(1,2)],2.3*E2(2,1)+[0 1.5*E2(2,2)],'-','color',[0 0.9 0],'linewidth',3*LW),
       
       text(2.3*E2(1,1)+1.2*1.5*E2(1,1),2.3*E2(2,1)+1.2*1.5*E2(2,1),'PC 1','color',[1 0.5 0],'fontsize',FS),
       text(2.3*E2(1,1)+1.2*1.5*E2(1,2),2.3*E2(2,1)+1.2*1.5*E2(2,2),'PC 2','color',[0 0.9 0],'fontsize',FS),
              
       
       % Origin and selected sample           
       figure(4),hold on,plot(0,0,'s','color',[1 0 0],'linewidth',2*LW,'markersize',10), 
                 hold on,plot(x_dat_1(1,sel_sample),x_dat_1(2,sel_sample),'o','color',[0 0 0],'linewidth',2*LW,'markersize',8)
                 axis equal
                     
       % Projections onto e2   
        pos1_1 = [datE2(1,:)*E2(1,1);datE2(1,:)*E2(2,1)];
         
        figure(4),hold on,plot(pos1_1(1,1:5:end),pos1_1(2,1:5:end),'.','color',[1 0.5 0]), % Projections onto e2                   
                          plot(pos1_1(1,sel_sample),pos1_1(2,sel_sample),'o','color',[1 0.5 0],'linewidth',2*LW,'markersize',8), % Projection onto e1
                          plot([pos1_1(1,sel_sample) x_dat_1(1,sel_sample)],[pos1_1(2,sel_sample) x_dat_1(2,sel_sample)],'--','color',[0 0 0],'linewidth',LW,'markersize',8)
                          axis equal
                                       
                 Res_PPA(2).ord

%
% SECOND POLYNOMIAL
%


% Data x_1                          
figure(5),clf,plot(x_dat_1(1,1:5:end),x_dat_1(2,1:5:end),'.','color',[0.65 0.65 0.65])
                  hold on,plot([p1(1) p2(1)],[p1(2) p2(2)],'-','color',[0 0 0])
                  hold on,plot([p2(1) p3(1)],[p2(2) p3(2)],'-','color',[0 0 0])
                  hold on,plot([p3(1) p4(1)],[p3(2) p4(2)],'-','color',[0 0 0])
                  hold on,plot([p4(1) p1(1)],[p4(2) p1(2)],'-','color',[0 0 0])
                  axis off
             
       % e2 and E2
       E2=Res_PPA(2).Res.V;
       e2 = E2(:,1);
        
       datE2 = E2'*x_dat_1;
           
       % Axis e2
       
       plot([-2.3*E2(1,1) 2.3*E2(1,1)],[-2.3*E2(2,1) 2.3*E2(2,1)],'-','color',[0 0 0]),
       
       plot(2.3*E2(1,1)+[0 1.5*E2(1,1)],2.3*E2(2,1)+[0 1.5*E2(2,1)],'-','color',[1 0.5 0],'linewidth',3*LW),
       plot(2.3*E2(1,1)+[0 1.5*E2(1,2)],2.3*E2(2,1)+[0 1.5*E2(2,2)],'-','color',[0 0.9 0],'linewidth',3*LW),
       
       % Origin and selected sample           
       % figure(5),hold on,plot(0,0,'s','color',[1 0 0],'linewidth',2*LW,'markersize',10), 
                 hold on,plot(x_dat_1(1,sel_sample),x_dat_1(2,sel_sample),'o','color',[0 0 0],'linewidth',2*LW,'markersize',8)
                 axis equal
                     
       % Projections onto e2   
        pos1_1 = [datE2(1,:)*E2(1,1);datE2(1,:)*E2(2,1)];
         
        figure(5),hold on,plot(pos1_1(1,1:5:end),pos1_1(2,1:5:end),'.','color',[1 0.5 0]), % Projections onto e2                   
                          plot(pos1_1(1,sel_sample),pos1_1(2,sel_sample),'o','color',[1 0.5 0],'linewidth',2*LW,'markersize',8), % Projection onto e1
                          plot([pos1_1(1,sel_sample) x_dat_1(1,sel_sample)],[pos1_1(2,sel_sample) x_dat_1(2,sel_sample)],'--','color',[0 0 0],'linewidth',LW,'markersize',8)
                          axis equal
                          
        W2 = Res_PPA(2).Res.W;
        ord2 = Res_PPA(2).ord
                          
                          
        V2 = my_vander(datE2(1,:),ord2);
        M2 = W2'*V2;
        
        x_pol2 = E2*[0*datE2(1,:);M2];
        
        x_dat_12 = x_dat_1 - x_pol2;  % Datos en el espacio 3d despues de restarles (a cada uno) la media condicional en el subespacio ortogonal
        
        x_dat_13 = x_dat_1 - E2*[datE2(1,:);M2];  % Datos en el espacio 3d despues de restarles (a cada uno) la media condicional y su proyeccion en e_1 -> proyectados en e2,e3
       
                              
        [jonde,ind]=sort(datE2(1,:));
        
        menos = 5;
        figure(5),hold on,plot(datE2(1,ind(menos:5:end-menos))*E2(1,1)+M2(ind(menos:5:end-menos))*E2(1,2),datE2(1,ind(menos:5:end-menos))*E2(2,1)+M2(ind(menos:5:end-menos))*E2(2,2),'-','color',[1 0 0],'linewidth',2*LW), % Projections onto e2                   
                          plot(pos1_1(1,sel_sample),pos1_1(2,sel_sample),'o','color',[1 0.5 0],'linewidth',2*LW,'markersize',8), % Projection onto e1
                          plot(datE2(1,sel_sample)*E2(1,1)+M2(sel_sample)*E2(1,2),datE2(1,sel_sample)*E2(2,1)+M2(sel_sample)*E2(2,2),'s','color',[1 0 0],'linewidth',2*LW), % Projections onto e2
                          plot([pos1_1(1,sel_sample) x_dat_1(1,sel_sample)],[pos1_1(2,sel_sample) x_dat_1(2,sel_sample)],'--','color',[0 0 0],'linewidth',LW,'markersize',8)
                          plot([datE2(1,sel_sample)*E2(1,1)+M2(sel_sample)*E2(1,2) x_dat_1(1,sel_sample)],[datE2(1,sel_sample)*E2(2,1)+M2(sel_sample)*E2(2,2) x_dat_1(2,sel_sample)],'-','color',[1 0 0],'linewidth',3*LW,'markersize',8)
                          plot([x_dat_1(1,sel_sample)],[x_dat_1(2,sel_sample)],'o','color',[0 0 0],'linewidth',2*LW,'markersize',8)
                          
        text(1.1*datE2(1,ind(end-menos))*E2(1,1)+1.1*M2(ind(end-menos))*E2(1,2),1.1*datE2(1,ind(end-menos))*E2(2,1)+1.1*M2(ind(end-menos))*E2(2,2),'PP 2','color',[1 0 0],'fontsize',FS), % Projections onto e2                                             
                          
                          axis equal
                          
                          
%
% REMOVE THE SECOND CONDITIONAL MEAN
%
                          
        x_pol2 = E2*[0*datE2(1,:);M2];
        
        x_dat_012 = x_dat_1 - x_pol2;  % Datos en el espacio 2d despues de restarles (a cada uno) la media condicional en el subespacio ortogonal
        
        x_dat_022 = x_dat_1 - E2*[datE2(1,:);M2];  % Datos en el espacio 2d despues de restarles (a cada uno) la media condicional y su proyeccion en e_2 -> proyectados en e2,e3

        
        
        % DATA AFTER REMOVING THE ESTIMATED CONDITIONAL MEAN
        figure(6),clf,plot(x_dat_012(1,1:5:end),x_dat_012(2,1:5:end),'.','color',[0.85 0.85 0])
        figure(6),hold on,plot([-2.3*E2(1,1) 2.3*E2(1,1)],[-2.3*E2(2,1) 2.3*E2(2,1)],'-','color',[0 0 0]),  
        axis equal     
        % CONDITIONAL MEANS IN THE ORIGiN (along e1) and
        figure(6),hold on,plot(pos1_1(1,1:5:end),pos1_1(2,1:5:end),'.','color',[1 0 0],'linewidth',2*LW), % Projections onto e1 
                          plot(pos1_1(1,sel_sample),pos1_1(2,sel_sample),'s','color',[1 0 0],'linewidth',2*LW,'markersize',8)
                          plot([pos1_1(1,sel_sample) x_dat_012(1,sel_sample)],[pos1_1(2,sel_sample) x_dat_012(2,sel_sample)],'-','color',[1 0 0],'linewidth',3*LW)                          
                          plot(x_dat_012(1,sel_sample),x_dat_012(2,sel_sample),'o','color',[0 0 0],'linewidth',2*LW)

                          
                          
                  hold on,plot([p1(1) p2(1)],[p1(2) p2(2)],'-','color',[0.65 0.65 0.65])
                  hold on,plot([p2(1) p3(1)],[p2(2) p3(2)],'-','color',[0.65 0.65 0.65])
                  hold on,plot([p3(1) p4(1)],[p3(2) p4(2)],'-','color',[0.65 0.65 0.65])
                  hold on,plot([p4(1) p1(1)],[p4(2) p1(2)],'-','color',[0.65 0.65 0.65])
                  axis off
                  
       % PROJECTION ONTO THE ORTHOGONAL SUBSPACE
        figure(6),hold on,plot(x_dat_022(1,1:5:end)+4*e2(1),x_dat_022(2,1:5:end)+4*e2(2),'.','color',[0.65 0.65 0.65])   
                  hold on,plot([-3*E2(1,2) 3*E2(1,2)]+4*e2(1),[-3*E2(2,2) 3*E2(2,2)]+4*e2(2),'-','color',[0 0 0])
                  plot([+4*e2(1) x_dat_022(1,sel_sample)+4*e2(1)],[+4*e2(2) x_dat_022(2,sel_sample)+4*e2(2)],'-','color',[1 0 0],'linewidth',3*LW)                           
                  plot(x_dat_022(1,sel_sample)+4*e2(1),x_dat_022(2,sel_sample)+4*e2(2),'o','color',[0 0 0],'linewidth',2*LW,'markersize',8)
                  hold on,plot(+4*e2(1),+4*e2(2),'s','color',[1 0 0],'linewidth',2*LW,'markersize',8)

% print(1,'-depsc',['/media/disk/vista/Papers/aranyas/JMLR2011/section_2_helix_example/fig1.eps'])
% print(2,'-depsc',['/media/disk/vista/Papers/aranyas/JMLR2011/section_2_helix_example/fig2.eps'])
% print(3,'-depsc',['/media/disk/vista/Papers/aranyas/JMLR2011/section_2_helix_example/fig3.eps'])
% print(4,'-depsc',['/media/disk/vista/Papers/aranyas/JMLR2011/section_2_helix_example/fig4.eps'])
% print(5,'-depsc',['/media/disk/vista/Papers/aranyas/JMLR2011/section_2_helix_example/fig5.eps'])
% print(6,'-depsc',['/media/disk/vista/Papers/aranyas/JMLR2011/section_2_helix_example/fig6.eps'])

           