function [Ex F Xis] = ppa_fs_frame_curvature(x,j,param_PPA,epsi,A_ref)

% [Ex F Xis] = ppa_fs_frame_curvature(x,j,param_PPA,epsi,A_ref)
%
% Input parameters:
%    x: point (in the input d-dimensional space) where the frame and curvatures are computed.
%    j: direction considered to define the tangent vector. j is a scalar in the range [1,d-1]
%    param_PPA: struct with the parameters of a PPA model.
%    epsi: step size for the discrete derivatives.
%    A_ref: Reference matrix for frame orientation.
%   
% Output parameters:
%
%    Ex: Struct that contains the vectors at x:
%        Assuming d dimensions we access the vectors in this way:
%                        Ex(i,1).e con i = 1:d
%    Xis: Matrix with the (d-1) generalized curvatures.
%
%    F: matrix with the vectors of the frenet-serret frame in columns
%

d = length(x);
datT = apply_PPA(x,param_PPA);
        
incr = zeros(d,d);
incr(j,:) = linspace(0,0+(d-1)*epsi,d);                
reticula_ppa = repmat(datT,1,d) + incr;
x = inv_PPA(reticula_ppa,param_PPA);

Xis = zeros(1,d-1);

x0 = x(:,1);
[J,struct_J] = PPA_jacobian_v(x0,param_PPA);
invJ = inv(J);

Ex(1,1).e = invJ(:,j)/norm(invJ(:,j));

for dim = 2:d % bucle sobre vectores de la base
    
    xdx = x(:,dim);
    [Jx,struct_Jx] = PPA_jacobian_v(xdx,param_PPA);
    invJ = inv(Jx);
     
    Ex(1,dim).e = invJ(:,j)/norm(invJ(:,j));    
    
    for i = 2:dim % bucle sobre derivadas necesarias
        
        epsilon = norm(abs(x(:,dim-i+2)-x(:,dim-i+1)));
        de = (Ex(i-1,dim-i+2).e - Ex(i-1,dim-i+1).e)/epsilon;
        
        % Gram-Schmidt
        ei = de;
        for k=1:i-1
            ei = ei - (de'*Ex(k,1).e)*Ex(k,1).e;
        end
        
        % Alineamos el vector con respecto a A_ref        
                
        norm_e = sqrt(sum(ei.^2));
        norm_r = sqrt(sum(A_ref(:,i).^2));       
        e_norm = ei/norm_e;
        r_norm = A_ref(:,i)/norm_r;
     
        prods_esc = e_norm'*r_norm;    
        ei = sign(prods_esc)*ei;
               
        % Normalization
        
        if i == dim
            Ex(i,1).e = ei/norm(ei);
            Xis(i-1) = abs(de'*Ex(i,1).e);
        else
            Ex(i,dim-i+1).e = ei/norm(ei);             
        end
        
    end
    
end

% Extraemos el frame de la estructura:
F = zeros(d);
for num_f=1:d
    F(:,num_f) = Ex(num_f,1).e;
end
